@@ -1,4 +1,4 @@
-from datetime import datetime, date
+from datetime import date, datetime
 
 import jdatetime
 from django.template import Library
